# WellKnownIssuerInfo

A collection of well known information about the issuer that is available to any authenticated user that is apart of the organisation the issuer is associated with. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**supported_mfa_methods** | **[str]** | A list of supported MFA methods. An empty list implies that no MFA methods are acceptable | 
**issuer_id** | **str** | Unique identifier | [optional] [readonly] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


